/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is
 * Henrik Gemal http://gemal.dk
 *
 * Portions created by the Initial Developer are Copyright (C) 2001-2004
 * the Initial Developer. All Rights Reserved.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var SlashyObject = function() {}

SlashyObject.prototype.trace = function(t) {
	var dev;
	try {
		var prefService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
		var pref = prefService.getBranch(null);
		dev = pref.getBoolPref("extensions.slashy.developer");
	} catch(err) {
	}
	if (dev) {
		var CONSOLE_SERVICE = Components.classes['@mozilla.org/consoleservice;1'].getService(Components.interfaces.nsIConsoleService);
		CONSOLE_SERVICE.logStringMessage("Slashy: " + t);
	}
}

SlashyObject.prototype.fixDoc = function(doc) {
	// the reg exp to look for and replace
	var re = new RegExp("\\\\|%5C", "g");
	// dont fix these link types
	var relink = new RegExp("^(javascript|file)", "i");

	// are there any links?
	if ("links" in doc && doc.links.length > 0) {
		Slashy.trace("has links");
		var lnks = doc.links;
		for (var i = 0; i < lnks.length; ++i) {
			if (!relink.test(lnks[i].href) && re.test(lnks[i].href)) {
				Slashy.trace("bad link: " + lnks[i].href);
				lnks[i].href = lnks[i].href.replace(re, "\/");
				Slashy.trace("fixed: " + lnks[i].href);
			}
		}
	}

	// are there any images?
	if ("images" in doc && doc.images.length > 0) {
		Slashy.trace("has images");
		var imgs = doc.images;
		for (var j = 0; j < imgs.length; ++j) {
			if (!relink.test(imgs[j].href) && re.test(imgs[j].src)) {
				Slashy.trace("bad image: " + imgs[j].src);
				imgs[j].src = imgs[j].src.replace(re, "\/");
				Slashy.trace("fixed: " + imgs[j].src);
			}
		}
	}
}

SlashyObject.prototype.fixSlash = function() {
	Slashy.trace("fixSlash");
	// try to get the current document
	var doc;
	var con;

	try {
		con = window.top.content;
		doc = window.top.content.document;
	} catch(err) {
		Slashy.trace("argh1:" + err);
	}
	if (doc) {
		Slashy.trace("got doc");
		Slashy.fixDoc(doc);
		if ("frames" in con && con.frames.length > 0) {
			Slashy.trace("got frames");
			for (var f = 0; f < con.frames.length; f++) {
				try {
					var fdoc = con.frames[f].document;
					if (fdoc) {
						Slashy.trace("got frame doc");
						Slashy.fixDoc(fdoc);
					}
				} catch(err) {
					Slashy.trace("argh2:" + err);
				}
			}
		}
	}
}

// create the object
const Slashy = new SlashyObject();
window.addEventListener("load", Slashy.fixSlash, true);
